@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,20 +16,31 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
-from google.api_core import retry as retries
+from google.api_core import retry_async as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.iam_credentials_v1 import gapic_version as package_version
 
 try:
-    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+    OptionalRetry = Union[retries.AsyncRetry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
-    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+    OptionalRetry = Union[retries.AsyncRetry, object]  # type: ignore
 
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -137,7 +148,7 @@ class IAMCredentialsAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -173,9 +184,9 @@ class IAMCredentialsAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, IAMCredentialsTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the iam credentials client.
@@ -219,14 +230,14 @@ class IAMCredentialsAsyncClient:
 
     async def generate_access_token(
         self,
-        request: Union[common.GenerateAccessTokenRequest, dict] = None,
+        request: Optional[Union[common.GenerateAccessTokenRequest, dict]] = None,
         *,
-        name: str = None,
-        delegates: Sequence[str] = None,
-        scope: Sequence[str] = None,
-        lifetime: duration_pb2.Duration = None,
+        name: Optional[str] = None,
+        delegates: Optional[MutableSequence[str]] = None,
+        scope: Optional[MutableSequence[str]] = None,
+        lifetime: Optional[duration_pb2.Duration] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.GenerateAccessTokenResponse:
         r"""Generates an OAuth 2.0 access token for a service
@@ -234,6 +245,13 @@ class IAMCredentialsAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iam_credentials_v1
 
             async def sample_generate_access_token():
@@ -243,7 +261,7 @@ class IAMCredentialsAsyncClient:
                 # Initialize request argument(s)
                 request = iam_credentials_v1.GenerateAccessTokenRequest(
                     name="name_value",
-                    scope=['scope_value_1', 'scope_value_2'],
+                    scope=['scope_value1', 'scope_value2'],
                 )
 
                 # Make the request
@@ -253,7 +271,7 @@ class IAMCredentialsAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.iam_credentials_v1.types.GenerateAccessTokenRequest, dict]):
+            request (Optional[Union[google.cloud.iam_credentials_v1.types.GenerateAccessTokenRequest, dict]]):
                 The request object.
             name (:class:`str`):
                 Required. The resource name of the service account for
@@ -266,7 +284,7 @@ class IAMCredentialsAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            delegates (:class:`Sequence[str]`):
+            delegates (:class:`MutableSequence[str]`):
                 The sequence of service accounts in a delegation chain.
                 Each service account must be granted the
                 ``roles/iam.serviceAccountTokenCreator`` role on its
@@ -284,7 +302,7 @@ class IAMCredentialsAsyncClient:
                 This corresponds to the ``delegates`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            scope (:class:`Sequence[str]`):
+            scope (:class:`MutableSequence[str]`):
                 Required. Code to identify the scopes
                 to be included in the OAuth 2.0 access
                 token. See
@@ -306,7 +324,7 @@ class IAMCredentialsAsyncClient:
                 This corresponds to the ``lifetime`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
@@ -343,7 +361,7 @@ class IAMCredentialsAsyncClient:
         # and friendly error handling.
         rpc = gapic_v1.method_async.wrap_method(
             self._client._transport.generate_access_token,
-            default_retry=retries.Retry(
+            default_retry=retries.AsyncRetry(
                 initial=0.1,
                 maximum=60.0,
                 multiplier=1.3,
@@ -376,14 +394,14 @@ class IAMCredentialsAsyncClient:
 
     async def generate_id_token(
         self,
-        request: Union[common.GenerateIdTokenRequest, dict] = None,
+        request: Optional[Union[common.GenerateIdTokenRequest, dict]] = None,
         *,
-        name: str = None,
-        delegates: Sequence[str] = None,
-        audience: str = None,
-        include_email: bool = None,
+        name: Optional[str] = None,
+        delegates: Optional[MutableSequence[str]] = None,
+        audience: Optional[str] = None,
+        include_email: Optional[bool] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.GenerateIdTokenResponse:
         r"""Generates an OpenID Connect ID token for a service
@@ -391,6 +409,13 @@ class IAMCredentialsAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iam_credentials_v1
 
             async def sample_generate_id_token():
@@ -410,7 +435,7 @@ class IAMCredentialsAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.iam_credentials_v1.types.GenerateIdTokenRequest, dict]):
+            request (Optional[Union[google.cloud.iam_credentials_v1.types.GenerateIdTokenRequest, dict]]):
                 The request object.
             name (:class:`str`):
                 Required. The resource name of the service account for
@@ -423,7 +448,7 @@ class IAMCredentialsAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            delegates (:class:`Sequence[str]`):
+            delegates (:class:`MutableSequence[str]`):
                 The sequence of service accounts in a delegation chain.
                 Each service account must be granted the
                 ``roles/iam.serviceAccountTokenCreator`` role on its
@@ -457,7 +482,7 @@ class IAMCredentialsAsyncClient:
                 This corresponds to the ``include_email`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
@@ -494,7 +519,7 @@ class IAMCredentialsAsyncClient:
         # and friendly error handling.
         rpc = gapic_v1.method_async.wrap_method(
             self._client._transport.generate_id_token,
-            default_retry=retries.Retry(
+            default_retry=retries.AsyncRetry(
                 initial=0.1,
                 maximum=60.0,
                 multiplier=1.3,
@@ -527,13 +552,13 @@ class IAMCredentialsAsyncClient:
 
     async def sign_blob(
         self,
-        request: Union[common.SignBlobRequest, dict] = None,
+        request: Optional[Union[common.SignBlobRequest, dict]] = None,
         *,
-        name: str = None,
-        delegates: Sequence[str] = None,
-        payload: bytes = None,
+        name: Optional[str] = None,
+        delegates: Optional[MutableSequence[str]] = None,
+        payload: Optional[bytes] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.SignBlobResponse:
         r"""Signs a blob using a service account's system-managed
@@ -541,6 +566,13 @@ class IAMCredentialsAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iam_credentials_v1
 
             async def sample_sign_blob():
@@ -560,7 +592,7 @@ class IAMCredentialsAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.iam_credentials_v1.types.SignBlobRequest, dict]):
+            request (Optional[Union[google.cloud.iam_credentials_v1.types.SignBlobRequest, dict]]):
                 The request object.
             name (:class:`str`):
                 Required. The resource name of the service account for
@@ -573,7 +605,7 @@ class IAMCredentialsAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            delegates (:class:`Sequence[str]`):
+            delegates (:class:`MutableSequence[str]`):
                 The sequence of service accounts in a delegation chain.
                 Each service account must be granted the
                 ``roles/iam.serviceAccountTokenCreator`` role on its
@@ -596,7 +628,7 @@ class IAMCredentialsAsyncClient:
                 This corresponds to the ``payload`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
@@ -631,7 +663,7 @@ class IAMCredentialsAsyncClient:
         # and friendly error handling.
         rpc = gapic_v1.method_async.wrap_method(
             self._client._transport.sign_blob,
-            default_retry=retries.Retry(
+            default_retry=retries.AsyncRetry(
                 initial=0.1,
                 maximum=60.0,
                 multiplier=1.3,
@@ -664,13 +696,13 @@ class IAMCredentialsAsyncClient:
 
     async def sign_jwt(
         self,
-        request: Union[common.SignJwtRequest, dict] = None,
+        request: Optional[Union[common.SignJwtRequest, dict]] = None,
         *,
-        name: str = None,
-        delegates: Sequence[str] = None,
-        payload: str = None,
+        name: Optional[str] = None,
+        delegates: Optional[MutableSequence[str]] = None,
+        payload: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.SignJwtResponse:
         r"""Signs a JWT using a service account's system-managed
@@ -678,6 +710,13 @@ class IAMCredentialsAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iam_credentials_v1
 
             async def sample_sign_jwt():
@@ -697,7 +736,7 @@ class IAMCredentialsAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.iam_credentials_v1.types.SignJwtRequest, dict]):
+            request (Optional[Union[google.cloud.iam_credentials_v1.types.SignJwtRequest, dict]]):
                 The request object.
             name (:class:`str`):
                 Required. The resource name of the service account for
@@ -710,7 +749,7 @@ class IAMCredentialsAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            delegates (:class:`Sequence[str]`):
+            delegates (:class:`MutableSequence[str]`):
                 The sequence of service accounts in a delegation chain.
                 Each service account must be granted the
                 ``roles/iam.serviceAccountTokenCreator`` role on its
@@ -736,7 +775,7 @@ class IAMCredentialsAsyncClient:
                 This corresponds to the ``payload`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
@@ -771,7 +810,7 @@ class IAMCredentialsAsyncClient:
         # and friendly error handling.
         rpc = gapic_v1.method_async.wrap_method(
             self._client._transport.sign_jwt,
-            default_retry=retries.Retry(
+            default_retry=retries.AsyncRetry(
                 initial=0.1,
                 maximum=60.0,
                 multiplier=1.3,
@@ -802,21 +841,16 @@ class IAMCredentialsAsyncClient:
         # Done; return the response.
         return response
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> "IAMCredentialsAsyncClient":
         return self
 
     async def __aexit__(self, exc_type, exc, tb):
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-iam",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("IAMCredentialsAsyncClient",)
