@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.iam_credentials_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -42,6 +54,7 @@ from google.cloud.iam_credentials_v1.types import common
 from .transports.base import DEFAULT_CLIENT_INFO, IAMCredentialsTransport
 from .transports.grpc import IAMCredentialsGrpcTransport
 from .transports.grpc_asyncio import IAMCredentialsGrpcAsyncIOTransport
+from .transports.rest import IAMCredentialsRestTransport
 
 
 class IAMCredentialsClientMeta(type):
@@ -57,10 +70,11 @@ class IAMCredentialsClientMeta(type):
     )  # type: Dict[str, Type[IAMCredentialsTransport]]
     _transport_registry["grpc"] = IAMCredentialsGrpcTransport
     _transport_registry["grpc_asyncio"] = IAMCredentialsGrpcAsyncIOTransport
+    _transport_registry["rest"] = IAMCredentialsRestTransport
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[IAMCredentialsTransport]:
         """Returns an appropriate transport class.
 
@@ -288,7 +302,7 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -343,8 +357,8 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, IAMCredentialsTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, IAMCredentialsTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the iam credentials client.
@@ -358,7 +372,7 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
             transport (Union[str, IAMCredentialsTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -388,6 +402,7 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -440,14 +455,14 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
 
     def generate_access_token(
         self,
-        request: Union[common.GenerateAccessTokenRequest, dict] = None,
+        request: Optional[Union[common.GenerateAccessTokenRequest, dict]] = None,
         *,
-        name: str = None,
-        delegates: Sequence[str] = None,
-        scope: Sequence[str] = None,
-        lifetime: duration_pb2.Duration = None,
+        name: Optional[str] = None,
+        delegates: Optional[MutableSequence[str]] = None,
+        scope: Optional[MutableSequence[str]] = None,
+        lifetime: Optional[duration_pb2.Duration] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.GenerateAccessTokenResponse:
         r"""Generates an OAuth 2.0 access token for a service
@@ -455,6 +470,13 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iam_credentials_v1
 
             def sample_generate_access_token():
@@ -464,7 +486,7 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
                 # Initialize request argument(s)
                 request = iam_credentials_v1.GenerateAccessTokenRequest(
                     name="name_value",
-                    scope=['scope_value_1', 'scope_value_2'],
+                    scope=['scope_value1', 'scope_value2'],
                 )
 
                 # Make the request
@@ -487,7 +509,7 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            delegates (Sequence[str]):
+            delegates (MutableSequence[str]):
                 The sequence of service accounts in a delegation chain.
                 Each service account must be granted the
                 ``roles/iam.serviceAccountTokenCreator`` role on its
@@ -505,7 +527,7 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
                 This corresponds to the ``delegates`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            scope (Sequence[str]):
+            scope (MutableSequence[str]):
                 Required. Code to identify the scopes
                 to be included in the OAuth 2.0 access
                 token. See
@@ -587,14 +609,14 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
 
     def generate_id_token(
         self,
-        request: Union[common.GenerateIdTokenRequest, dict] = None,
+        request: Optional[Union[common.GenerateIdTokenRequest, dict]] = None,
         *,
-        name: str = None,
-        delegates: Sequence[str] = None,
-        audience: str = None,
-        include_email: bool = None,
+        name: Optional[str] = None,
+        delegates: Optional[MutableSequence[str]] = None,
+        audience: Optional[str] = None,
+        include_email: Optional[bool] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.GenerateIdTokenResponse:
         r"""Generates an OpenID Connect ID token for a service
@@ -602,6 +624,13 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iam_credentials_v1
 
             def sample_generate_id_token():
@@ -634,7 +663,7 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            delegates (Sequence[str]):
+            delegates (MutableSequence[str]):
                 The sequence of service accounts in a delegation chain.
                 Each service account must be granted the
                 ``roles/iam.serviceAccountTokenCreator`` role on its
@@ -728,13 +757,13 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
 
     def sign_blob(
         self,
-        request: Union[common.SignBlobRequest, dict] = None,
+        request: Optional[Union[common.SignBlobRequest, dict]] = None,
         *,
-        name: str = None,
-        delegates: Sequence[str] = None,
-        payload: bytes = None,
+        name: Optional[str] = None,
+        delegates: Optional[MutableSequence[str]] = None,
+        payload: Optional[bytes] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.SignBlobResponse:
         r"""Signs a blob using a service account's system-managed
@@ -742,6 +771,13 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iam_credentials_v1
 
             def sample_sign_blob():
@@ -774,7 +810,7 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            delegates (Sequence[str]):
+            delegates (MutableSequence[str]):
                 The sequence of service accounts in a delegation chain.
                 Each service account must be granted the
                 ``roles/iam.serviceAccountTokenCreator`` role on its
@@ -855,13 +891,13 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
 
     def sign_jwt(
         self,
-        request: Union[common.SignJwtRequest, dict] = None,
+        request: Optional[Union[common.SignJwtRequest, dict]] = None,
         *,
-        name: str = None,
-        delegates: Sequence[str] = None,
-        payload: str = None,
+        name: Optional[str] = None,
+        delegates: Optional[MutableSequence[str]] = None,
+        payload: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.SignJwtResponse:
         r"""Signs a JWT using a service account's system-managed
@@ -869,6 +905,13 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iam_credentials_v1
 
             def sample_sign_jwt():
@@ -901,7 +944,7 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            delegates (Sequence[str]):
+            delegates (MutableSequence[str]):
                 The sequence of service accounts in a delegation chain.
                 Each service account must be granted the
                 ``roles/iam.serviceAccountTokenCreator`` role on its
@@ -983,7 +1026,7 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "IAMCredentialsClient":
         return self
 
     def __exit__(self, type, value, traceback):
@@ -997,14 +1040,9 @@ class IAMCredentialsClient(metaclass=IAMCredentialsClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-iam",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("IAMCredentialsClient",)
