@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.iam_v2beta import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,6 +48,7 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+from google.longrunning import operations_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 
 from google.cloud.iam_v2beta.services.policies import pagers
@@ -61,7 +74,7 @@ class PoliciesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[PoliciesTransport]:
         """Returns an appropriate transport class.
 
@@ -168,21 +181,6 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
         """
         return self._transport
 
-    @staticmethod
-    def policy_path(
-        policy: str,
-    ) -> str:
-        """Returns a fully-qualified policy string."""
-        return "policies/{policy}".format(
-            policy=policy,
-        )
-
-    @staticmethod
-    def parse_policy_path(path: str) -> Dict[str, str]:
-        """Parses a policy path into its component segments."""
-        m = re.match(r"^policies/(?P<policy>.+?)$", path)
-        return m.groupdict() if m else {}
-
     @staticmethod
     def common_billing_account_path(
         billing_account: str,
@@ -276,7 +274,7 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -331,8 +329,8 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, PoliciesTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, PoliciesTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the policies client.
@@ -346,7 +344,7 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
             transport (Union[str, PoliciesTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -376,6 +374,7 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -428,11 +427,11 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
 
     def list_policies(
         self,
-        request: Union[policy.ListPoliciesRequest, dict] = None,
+        request: Optional[Union[policy.ListPoliciesRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPoliciesPager:
         r"""Retrieves the policies of the specified kind that are
@@ -443,6 +442,13 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iam_v2beta
 
             def sample_list_policies():
@@ -463,7 +469,7 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
 
         Args:
             request (Union[google.cloud.iam_v2beta.types.ListPoliciesRequest, dict]):
-                The request object. Request message for `ListPolicies`.
+                The request object. Request message for ``ListPolicies``.
             parent (str):
                 Required. The resource that the policy is attached to,
                 along with the kind of policy to list. Format:
@@ -549,17 +555,24 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
 
     def get_policy(
         self,
-        request: Union[policy.GetPolicyRequest, dict] = None,
+        request: Optional[Union[policy.GetPolicyRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy.Policy:
         r"""Gets a policy.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iam_v2beta
 
             def sample_get_policy():
@@ -579,7 +592,7 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
 
         Args:
             request (Union[google.cloud.iam_v2beta.types.GetPolicyRequest, dict]):
-                The request object. Request message for `GetPolicy`.
+                The request object. Request message for ``GetPolicy``.
             name (str):
                 Required. The resource name of the policy to retrieve.
                 Format:
@@ -651,19 +664,26 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
 
     def create_policy(
         self,
-        request: Union[gi_policy.CreatePolicyRequest, dict] = None,
+        request: Optional[Union[gi_policy.CreatePolicyRequest, dict]] = None,
         *,
-        parent: str = None,
-        policy: gi_policy.Policy = None,
-        policy_id: str = None,
+        parent: Optional[str] = None,
+        policy: Optional[gi_policy.Policy] = None,
+        policy_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Creates a policy.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iam_v2beta
 
             def sample_create_policy():
@@ -687,7 +707,7 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
 
         Args:
             request (Union[google.cloud.iam_v2beta.types.CreatePolicyRequest, dict]):
-                The request object. Request message for `CreatePolicy`.
+                The request object. Request message for ``CreatePolicy``.
             parent (str):
                 Required. The resource that the policy is attached to,
                 along with the kind of policy to create. Format:
@@ -793,10 +813,10 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
 
     def update_policy(
         self,
-        request: Union[policy.UpdatePolicyRequest, dict] = None,
+        request: Optional[Union[policy.UpdatePolicyRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Updates the specified policy.
@@ -815,6 +835,13 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iam_v2beta
 
             def sample_update_policy():
@@ -837,7 +864,7 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
 
         Args:
             request (Union[google.cloud.iam_v2beta.types.UpdatePolicyRequest, dict]):
-                The request object. Request message for `UpdatePolicy`.
+                The request object. Request message for ``UpdatePolicy``.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -894,17 +921,24 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
 
     def delete_policy(
         self,
-        request: Union[policy.DeletePolicyRequest, dict] = None,
+        request: Optional[Union[policy.DeletePolicyRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Deletes a policy. This action is permanent.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iam_v2beta
 
             def sample_delete_policy():
@@ -928,7 +962,7 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
 
         Args:
             request (Union[google.cloud.iam_v2beta.types.DeletePolicyRequest, dict]):
-                The request object. Request message for `DeletePolicy`.
+                The request object. Request message for ``DeletePolicy``.
             name (str):
                 Required. The resource name of the policy to delete.
                 Format:
@@ -1011,7 +1045,7 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "PoliciesClient":
         return self
 
     def __exit__(self, type, value, traceback):
@@ -1024,15 +1058,64 @@ class PoliciesClient(metaclass=PoliciesClientMeta):
         """
         self.transport.close()
 
+    def get_operation(
+        self,
+        request: Optional[operations_pb2.GetOperationRequest] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operations_pb2.Operation:
+        r"""Gets the latest state of a long-running operation.
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-iam",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+        Args:
+            request (:class:`~.operations_pb2.GetOperationRequest`):
+                The request object. Request message for
+                `GetOperation` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                    if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            ~.operations_pb2.Operation:
+                An ``Operation`` object.
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = operations_pb2.GetOperationRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._transport.get_operation,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("PoliciesClient",)
